@@ -7,12 +7,12 @@
 
 import unittest
 
+from decorator import Retry
+
 
 class TestDecorator(unittest.TestCase):
 
     def test_retry(self):
-        from decorator.retry import Retry
-
         @Retry(tries=3, delay=3)
         def test(*args, **kwargs):
             print("test")
@@ -20,8 +20,3 @@ class TestDecorator(unittest.TestCase):
 
         with self.assertRaises(ZeroDivisionError):
             test()
-
-    def test_async(self):
-        from decorator.async import Async
-
-        print("a")
\ No newline at end of file
