@@ -10,7 +10,7 @@ import unittest
 class TestMysql(unittest.TestCase):
 
     def test_import(self):
-        from db_cmd.mysql import ExecuteMysql
+        from db import ExecuteMysql
         func = ExecuteMysql.create_new_report
         # 判断func是否是方法
         self.assertTrue(callable(func))
